@@ -28,7 +28,7 @@ a simple example::
 
     dwg = svgwrite.Drawing('test.svg', profile='tiny')
     dwg.add(dwg.line((0, 0), (10, 0), stroke=svgwrite.rgb(10, 10, 16, '%')))
-    dwg.add(dwg.text('Test', insert=(0, 0.2))
+    dwg.add(dwg.text('Test', insert=(0, 0.2)))
     dwg.save()
 
 SVG Version
@@ -41,7 +41,7 @@ You can only create two types of SVG drawings:
 
 """
 
-version = (1, 1, 4)  # also update setup.py
+version = (1, 1, 8)  # also update setup.py
 VERSION = '%d.%d.%d' % version
 
 AUTHOR_NAME = 'Manfred Moitzi'
